# This file is generated by C:\Miniconda3\conda-bld\numexpr_1534365035897\work\setup.py

# It contains system_info results at the time of building this package.

__all__ = ["get_info","show"]



mkl_info={'libraries': ['mkl_rt'], 'library_dirs': ['C:/Miniconda3/conda-bld/numexpr_1534365035897/_h_env\\Library\\lib'], 'define_macros': [('SCIPY_MKL_H', None), ('HAVE_CBLAS', None)], 'include_dirs': ['C:/Miniconda3/conda-bld/numexpr_1534365035897/_h_env\\Library\\include']}



def get_info(name):

    g = globals()

    return g.get(name, g.get(name + "_info", {}))



def show():

    for name,info_dict in list(globals().items()):

        if name[0] == "_" or type(info_dict) is not type({}): continue

        print((name + ":"))

        if not info_dict:

            print("  NOT AVAILABLE")

        for k,v in list(info_dict.items()):

            v = str(v)

            if k == "sources" and len(v) > 200:

                v = v[:60] + " ...\n... " + v[-60:]

            print(("    %s = %s" % (k,v)))

    